@@ -19,7 +19,10 @@ where
     impl_raw_value_type!();
 
     fn schema_ref() -> MetaSchemaRef {
-        MetaSchemaRef::Inline(Box::new(MetaSchema::new("object")))
+        MetaSchemaRef::Inline(Box::new(MetaSchema {
+            additional_properties: Some(Box::new(V::schema_ref())),
+            ..MetaSchema::new("object")
+        }))
     }
 }
 
@@ -36,7 +39,7 @@ where
                 let key = key
                     .parse()
                     .map_err(|err| ParseError::custom(format!("object key: {}", err)))?;
-                let value = ParseFromJSON::parse_from_json(value).map_err(ParseError::propagate)?;
+                let value = V::parse_from_json(value).map_err(ParseError::propagate)?;
                 obj.insert(key, value);
             }
             Ok(obj)
@@ -59,3 +62,21 @@ where
         Value::Object(map)
     }
 }
+
+#[cfg(test)]
+mod tests {
+    use super::*;
+
+    #[test]
+    fn test_hashmap() {
+        type MyObj = HashMap<String, i32>;
+
+        assert_eq!(
+            MyObj::schema_ref().unwrap_inline(),
+            &MetaSchema {
+                additional_properties: Some(Box::new(i32::schema_ref())),
+                ..MetaSchema::new("object")
+            }
+        );
+    }
+}
